@@ -48,6 +48,15 @@ def disable_imports():
     __builtins__["__import__"] = no_imports_importer
 
 
+@contextmanager
+def disabled_imports():
+    disable_imports()
+    try:
+        yield
+    finally:
+        enable_imports()
+
+
 def allow_imports(func):
     def wrapper(*args, **kwargs):
         imported = __builtins__["__import__"]
@@ -59,6 +68,17 @@ def allow_imports(func):
     return wrapper
 
 
+def mark_allowed_imports(obj):
+    for method_name in dir(obj):
+        if not method_name.startswith("_") and callable(
+            inspect.getattr_static(obj, method_name)  # to avoid calling props
+        ):
+            setattr(
+                obj, method_name, allow_imports(getattr(obj, method_name)),
+            )
+    return obj
+
+
 def prepare_event(event):
     if isinstance(event, str):
         event = getattr(
