@@ -1,8 +1,14 @@
 import pytest
 
+from bitccl.state import config as config_ctx
 from bitccl.utils import prepare_event
 
 
+@pytest.fixture(autouse=True)
+def config():
+    config_ctx.set({})
+
+
 def pytest_addoption(parser):
     parser.addoption(
         "--runslow", action="store_true", default=False, help="run slow tests"
